@@ -37,13 +37,13 @@ extern "C" {
 #include <vector>
 #include <random>
 #include <algorithm>
-#include <attr/xattr.h>
+#include <sys/xattr.h>
 #include <sys/types.h>
 #include <sys/syscall.h>
 #include <sys/file.h>
 #include <stddef.h>
 
-#define DISORDERFS_VERSION "0.5.3"
+#define DISORDERFS_VERSION "0.5.4"
 
 namespace {
 	std::vector<std::string>	bare_arguments;
@@ -425,12 +425,14 @@ int	main (int argc, char** argv)
 		if (!d) {
 			return -errno;
 		}
-		struct dirent	dirent_storage;
 		struct dirent*	dirent_p;
-		int		res;
-		while ((res = readdir_r(d, &dirent_storage, &dirent_p)) == 0 && dirent_p) {
+		errno = 0;
+		while ((dirent_p = readdir(d)) != NULL) {
 			dirents->emplace_back(std::make_pair(dirent_p->d_name, dirent_p->d_ino));
 		}
+		if (errno != 0) {
+			return -errno;
+		}
 		if (config.sort_dirents) {
 			std::sort(dirents->begin(), dirents->end());
 		}
@@ -438,8 +440,8 @@ int	main (int argc, char** argv)
 			std::reverse(dirents->begin(), dirents->end());
 		}
 		closedir(d);
-		if (res != 0) {
-			return -res;
+		if (errno != 0) {
+			return -errno;
 		}
 
 		set_fuse_data<Dirents*>(info, dirents.release());
